@@ -1,4 +1,4 @@
-__version__ = '0.44.0'
+__version__ = '0.45.0'
 
 from json import loads, JSONDecodeError
 from typing import TypedDict as _TypedDict
@@ -26,9 +26,6 @@ _INDEX_CHANGE_MATCH = _rc(rf"<div[^>]*>(\()?{_F}\)?</div>(?: {_F}%)?").match
 _INDEX_TIMESTAMP_MATCH = _rc(r'(\d\d)/(\d+)/(\d+) (\d\d):(\d\d):(\d\d)').match
 
 
-_DF = _partial(_DataFrame, copy=False)
-
-
 _jstrptime = _jdatetime.strptime
 
 
@@ -88,9 +85,9 @@ def _parse_ombud_messages(text) -> _DataFrame:
     headers = _findall(r'<th>(.+?)</th>', text)
     dates = _findall(r"<th class='ltr'>(.+?)</th>", text)
     descriptions = _findall(r'<td colspan="2">(.+?)<hr />\s*</td>', text)
-    df = _DF({
+    df = _DataFrame({
         'header': headers, 'date': dates, 'description': descriptions
-    }, dtype='string')
+    }, dtype='string', copy=False)
     if dates:  # pandas cannot do ('14' + df['date']) on empty dates
         df['date'] = ('14' + df['date']).apply(
             _jstrptime, format='%Y/%m/%d %H:%M')
@@ -113,7 +110,7 @@ class Session:
     def __new__(cls, *args, **kwargs) -> _ClientSession:
         global SESSION
         if 'timeout' not in kwargs:
-            kwargs['timeout'] = _ClientTimeout(total=30., sock_connect=5., sock_read=5.)
+            kwargs['timeout'] = _ClientTimeout(total=30., sock_connect=10., sock_read=10.)
         SESSION = _ClientSession(**kwargs)
         return SESSION
 
@@ -156,7 +153,7 @@ async def _api(path: str):
     try:
         return loads(content)
     except JSONDecodeError:
-        error(f'{path=}\n{content=}')
+        error(f'url={_API}{path}\n{content=}')
         raise
 
 
